pub struct MemoryAllocator { /* private fields */ }Implementations
Sourceimpl MemoryAllocator
impl MemoryAllocator
pub fn new() -> Self
pub fn allocate(&mut self, size: MemorySize) -> *mut u8
Sourcepub unsafe fn deallocate(&mut self, ptr: *mut u8, size: MemorySize)
pub unsafe fn deallocate(&mut self, ptr: *mut u8, size: MemorySize)
Safety
The caller must ensure that:
ptris a valid pointer that was previously allocated by this allocatorsizematches the size that was used when allocatingptrptris not null
pub fn get_stats(&self) -> AllocatorStats
pub fn reset_stats(&mut self)